# Geist Templates

## What is a Geist template?

A Geist template is a text file without a specific extension requirement although adding a `.geist` extension is recommended. It is an extension of a [Jinja template](https://jinja.palletsprojects.com/en/3.1.x/templates/), therefore it follows the default Jinja delimiters:

- `{% ... %}` for Statements
- `{{ ... }}` for Expressions to print to the template output
- `{# ... #}` for Comments not included in the template output

## How to write a Geist template?

A Geist template relies on tags and filters.

### Tags

Tags are used within the statements, i.e., `{% ... %}`. There are two types of tags, `StandaloneTag` and `ContainerTag`. While the `StandaloneTag` does not require a closing tag, the `ContainerTag` does. Besides the Jinja predefined tags (e.g., `for`), Geist supports the following tags:

`StandaloneTag`:

- [destroy](tags/tag-destroy.md)
- [graph](tags/tag-graph.md)
- [graph2](tags/tag-graph2.md)
- [use](tags/tag-use.md)

`ContainerTag`:

- [create](tags/tag-create.md)
- [load](tags/tag-load.md)
- [query](tags/tag-query.md)
- [component](tags/tag-component.md)
- [map](tags/tag-map.md)
- [html](tags/tag-html.md)
- [img](tags/tag-img.md)
- [table](tags/tag-table.md)

Custom tags can be defined through files with the [use](tags/tag-use.md) tag.

### Filters

Filters are used to modify variables. Each filter can only take one variable as input. Multiple filters can be applied to a single variable in sequence. For example, `{{ var|filter1|filter2|filter3 }}` denotes the variable `var` will be processed through `filter1` first, then `filter2`, and `filter3` at the end.

Geist supports the following filters:

- **head**: extract the first 5 rows of a Pandas data frame
- **csv2df**: convert a CSV string to a Pandas data frame
- **json2df**: convert a JSON string to a Pandas data frame
- **dict2df**: convert a dictionary to a Pandas data frame
- **json2dict**: convert a JSON string to a dictionary
- **df2json**: convert a Pandas data frame to a JSON string
- **df2htmltable**: convert a Pandas data frame to an HTML table
- **escape_quotes**: escape both double and single quotation marks
- **process_str_for_html**: preprocess a string to be displayed within an HTML document, e.g., replace `<` with `&lt`

## How to execute (expand) a Geist template?

=== "CLI"

    --8<--
    cli/report.md
    --8<--

=== "Python API"

    --8<--
    python-api/report.md
    --8<--